diff -pruN 1.10.8-1/CHANGELOG.md 1.10.9-1/CHANGELOG.md
--- 1.10.8-1/CHANGELOG.md	2020-07-09 05:46:32.000000000 +0000
+++ 1.10.9-1/CHANGELOG.md	2020-08-02 06:46:43.000000000 +0000
@@ -1,3 +1,10 @@
+### [1.10.9] 2020-07-16
+
+  * Fixed Bitbucket redirect loop when credentials are outdated
+  * Fixed GitLab auth prompt wording
+  * Fixed `self-update` handling of files requiring admin permissions to write to on Windows (it now does a UAC prompt)
+  * Fixed parsing issues in funding.yml files
+
 ### [1.10.8] 2020-06-24
 
   * Fixed compatibility issue with git being configured to show signatures by default
@@ -866,6 +873,7 @@
 
   * Initial release
 
+[1.10.9]: https://github.com/composer/composer/compare/1.10.8...1.10.9
 [1.10.8]: https://github.com/composer/composer/compare/1.10.7...1.10.8
 [1.10.7]: https://github.com/composer/composer/compare/1.10.6...1.10.7
 [1.10.6]: https://github.com/composer/composer/compare/1.10.5...1.10.6
diff -pruN 1.10.8-1/debian/changelog 1.10.9-1/debian/changelog
--- 1.10.8-1/debian/changelog	2020-07-09 05:52:38.000000000 +0000
+++ 1.10.9-1/debian/changelog	2020-08-02 07:03:35.000000000 +0000
@@ -1,3 +1,10 @@
+composer (1.10.9-1) unstable; urgency=medium
+
+  [ Jordi Boggiano ]
+  * Release 1.10.9
+
+ -- David Prévot <taffit@debian.org>  Sun, 02 Aug 2020 09:03:35 +0200
+
 composer (1.10.8-1) unstable; urgency=medium
 
   [ Jordi Boggiano ]
diff -pruN 1.10.8-1/.github/workflows/continuous-integration.yml 1.10.9-1/.github/workflows/continuous-integration.yml
--- 1.10.8-1/.github/workflows/continuous-integration.yml	2020-07-09 05:46:32.000000000 +0000
+++ 1.10.9-1/.github/workflows/continuous-integration.yml	2020-08-02 06:46:43.000000000 +0000
@@ -38,14 +38,6 @@ jobs:
             dependencies: highest
             os: ubuntu-latest
             experimental: false
-          - php-version: 5.3
-            dependencies: lowest
-            os: ubuntu-latest
-            experimental: false
-          - php-version: 7.4
-            dependencies: highest
-            os: ubuntu-latest
-            experimental: true # TODO fix build errors there if possible
           - php-version: 7.4
             os: windows-latest
             dependencies: locked
@@ -54,10 +46,6 @@ jobs:
             os: macos-latest
             dependencies: locked
             experimental: false
-          - php-version: 8.0
-            dependencies: highest
-            os: ubuntu-latest
-            experimental: true
 
     steps:
       - name: "Checkout"
diff -pruN 1.10.8-1/src/Composer/Command/SelfUpdateCommand.php 1.10.9-1/src/Composer/Command/SelfUpdateCommand.php
--- 1.10.8-1/src/Composer/Command/SelfUpdateCommand.php	2020-07-09 05:46:32.000000000 +0000
+++ 1.10.9-1/src/Composer/Command/SelfUpdateCommand.php	2020-08-02 06:46:43.000000000 +0000
@@ -16,6 +16,7 @@ use Composer\Composer;
 use Composer\Factory;
 use Composer\Config;
 use Composer\Util\Filesystem;
+use Composer\Util\Platform;
 use Composer\SelfUpdate\Keys;
 use Composer\SelfUpdate\Versions;
 use Composer\IO\IOInterface;
@@ -106,6 +107,11 @@ EOT
             return $this->fetchKeys($io, $config);
         }
 
+        // ensure composer.phar location is accessible
+        if (!file_exists($localFilename)) {
+            throw new FilesystemException('Composer update failed: the "'.$localFilename.'" is not accessible');
+        }
+
         // check if current dir is writable and if not try the cache dir from settings
         $tmpDir = is_writable(dirname($localFilename)) ? dirname($localFilename) : $cacheDir;
 
@@ -248,10 +254,8 @@ TAGSPUBKEY
             $this->cleanBackups($rollbackDir);
         }
 
-        if ($err = $this->setLocalPhar($localFilename, $tempFilename, $backupFile)) {
+        if (!$this->setLocalPhar($localFilename, $tempFilename, $backupFile)) {
             @unlink($tempFilename);
-            $io->writeError('<error>The file is corrupted ('.$err->getMessage().').</error>');
-            $io->writeError('<error>Please re-run the self-update command to try again.</error>');
 
             return 1;
         }
@@ -331,9 +335,7 @@ TAGSPUBKEY
 
         $io = $this->getIO();
         $io->writeError(sprintf("Rolling back to version <info>%s</info>.", $rollbackVersion));
-        if ($err = $this->setLocalPhar($localFilename, $oldFile)) {
-            $io->writeError('<error>The backup file was corrupted ('.$err->getMessage().').</error>');
-
+        if (!$this->setLocalPhar($localFilename, $oldFile)) {
             return 1;
         }
 
@@ -341,37 +343,49 @@ TAGSPUBKEY
     }
 
     /**
-     * @param  string                                        $localFilename
-     * @param  string                                        $newFilename
-     * @param  string                                        $backupTarget
-     * @throws \Exception
-     * @return \UnexpectedValueException|\PharException|null
+     * Checks if the downloaded/rollback phar is valid then moves it
+     *
+     * @param  string $localFilename The composer.phar location
+     * @param  string $newFilename The downloaded or backup phar
+     * @param  string $backupTarget The filename to use for the backup
+     * @throws \FilesystemException If the file cannot be moved
+     * @return bool Whether the phar is valid and has been moved
      */
     protected function setLocalPhar($localFilename, $newFilename, $backupTarget = null)
     {
-        try {
-            @chmod($newFilename, fileperms($localFilename));
-            if (!ini_get('phar.readonly')) {
-                // test the phar validity
-                $phar = new \Phar($newFilename);
-                // free the variable to unlock the file
-                unset($phar);
-            }
+        $io = $this->getIO();
+        @chmod($newFilename, fileperms($localFilename));
+
+        // check phar validity
+        if (!$this->validatePhar($newFilename, $error)) {
+            $io->writeError('<error>The '.($backupTarget ? 'update' : 'backup').' file is corrupted ('.$error.')</error>');
 
-            // copy current file into installations dir
-            if ($backupTarget && file_exists($localFilename)) {
-                @copy($localFilename, $backupTarget);
+            if ($backupTarget) {
+                $io->writeError('<error>Please re-run the self-update command to try again.</error>');
             }
 
+            return false;
+        }
+
+        // copy current file into backups dir
+        if ($backupTarget) {
+            @copy($localFilename, $backupTarget);
+        }
+
+        try {
             rename($newFilename, $localFilename);
 
-            return null;
+            return true;
         } catch (\Exception $e) {
-            if (!$e instanceof \UnexpectedValueException && !$e instanceof \PharException) {
-                throw $e;
+            // see if we can run this operation as an Admin on Windows
+            if (!is_writable(dirname($localFilename))
+                && $io->isInteractive()
+                && $this->isWindowsNonAdminUser($isCygwin)) {
+                return $this->tryAsWindowsAdmin($localFilename, $newFilename, $isCygwin);
             }
 
-            return $e;
+            $action = 'Composer '.($backupTarget ? 'update' : 'rollback');
+            throw new FilesystemException($action.' failed: "'.$localFilename.'" could not be written.'.PHP_EOL.$e->getMessage());
         }
     }
 
@@ -414,4 +428,129 @@ TAGSPUBKEY
 
         return $finder;
     }
+
+    /**
+     * Validates the downloaded/backup phar file
+     *
+     * @param string $pharFile The downloaded or backup phar
+     * @param null|string $error Set by method on failure
+     *
+     * Code taken from getcomposer.org/installer. Any changes should be made
+     * there and replicated here
+     *
+     * @return bool If the operation succeeded
+     * @throws \Exception
+     */
+    protected function validatePhar($pharFile, &$error)
+    {
+        if (ini_get('phar.readonly')) {
+            return true;
+        }
+
+        try {
+            // Test the phar validity
+            $phar = new \Phar($pharFile);
+            // Free the variable to unlock the file
+            unset($phar);
+            $result = true;
+        } catch (\Exception $e) {
+            if (!$e instanceof \UnexpectedValueException && !$e instanceof \PharException) {
+                throw $e;
+            }
+            $error = $e->getMessage();
+            $result = false;
+        }
+
+        return $result;
+    }
+
+    /**
+     * Returns true if this is a non-admin Windows user account
+     *
+     * @param null|bool $isCygwin Set by method
+     * @return bool
+     */
+    protected function isWindowsNonAdminUser(&$isCygwin)
+    {
+        $isCygwin = preg_match('/cygwin/i', php_uname());
+
+        if (!$isCygwin && !Platform::isWindows()) {
+            return false;
+        }
+
+        // fltmc.exe manages filter drivers and errors without admin privileges
+        $command = sprintf('%sfltmc.exe filters', $isCygwin ? 'cmd.exe /c ' : '');
+        exec($command, $output, $exitCode);
+
+        return $exitCode !== 0;
+    }
+
+    /**
+     * Invokes a UAC prompt to update composer.phar as an admin
+     *
+     * Uses a .vbs script to elevate and run the cmd.exe move command.
+     *
+     * @param string $localFilename The composer.phar location
+     * @param string $newFilename The downloaded or backup phar
+     * @param bool $isCygwin Whether we are running on Cygwin
+     * @return bool Whether composer.phar has been updated
+     */
+    protected function tryAsWindowsAdmin($localFilename, $newFilename, $isCygwin)
+    {
+        $io = $this->getIO();
+
+        $io->writeError('<error>Unable to write "'.$localFilename.'". Access is denied.</error>');
+        $helpMessage = 'Please run the self-update command as an Administrator.';
+        $question = 'Complete this operation with Administrator privileges [<comment>Y,n</comment>]? ';
+
+        if (!$io->askConfirmation($question, false)) {
+            $io->writeError('<warning>Operation cancelled. '.$helpMessage.'</warning>');
+
+            return false;
+        }
+
+        $tmpFile = tempnam(sys_get_temp_dir(), '');
+        $script = $tmpFile.'.vbs';
+        rename($tmpFile, $script);
+
+        $checksum = hash_file('sha256', $newFilename);
+
+        // format the file names for cmd.exe
+        if ($isCygwin) {
+            $source = exec(sprintf("cygpath -w '%s'", $newFilename));
+            $destination = exec(sprintf("cygpath -w '%s'", $localFilename));
+        } else {
+            // cmd's internal move is fussy about backslashes
+            $source = str_replace('/', '\\', $newFilename);
+            $destination = str_replace('/', '\\', $localFilename);
+        }
+
+        $vbs = <<<EOT
+Set UAC = CreateObject("Shell.Application")
+UAC.ShellExecute "cmd.exe", "/c move /y ""$source"" ""$destination""", "", "runas", 0
+Wscript.Sleep(300)
+EOT;
+
+        file_put_contents($script, $vbs);
+
+        if ($isCygwin) {
+            chmod($script, 0755);
+            $cygscript = sprintf('"%s"', exec(sprintf("cygpath -w '%s'", $script)));
+            $command = sprintf("cmd.exe /c '%s'", $cygscript);
+        } else {
+            $command = sprintf('"%s"', $script);
+        }
+
+        exec($command);
+        @unlink($script);
+
+        // see if the file was moved
+        if ($result = (hash_file('sha256', $localFilename) === $checksum)) {
+            $io->writeError('<info>Operation succeeded.</info>');
+        } else {
+            $io->writeError('<error>Operation failed (file not written). '.$helpMessage.'</error>');
+        };
+
+        return $result;
+    }
 }
diff -pruN 1.10.8-1/src/Composer/Composer.php 1.10.9-1/src/Composer/Composer.php
--- 1.10.8-1/src/Composer/Composer.php	2020-07-09 05:46:32.000000000 +0000
+++ 1.10.9-1/src/Composer/Composer.php	2020-08-02 06:46:43.000000000 +0000
@@ -45,14 +45,14 @@ class Composer
      * const SOURCE_VERSION = '';
      *
      * source (git clone):
-     * const VERSION = '1.10.8';
+     * const VERSION = '1.10.9';
      * const BRANCH_ALIAS_VERSION = '';
-     * const RELEASE_DATE = '2020-06-24 21:23:30';
+     * const RELEASE_DATE = '2020-07-16 12:57:00';
      * const SOURCE_VERSION = '1.8-dev+source';
      */
-    const VERSION = '1.10.8';
+    const VERSION = '1.10.9';
     const BRANCH_ALIAS_VERSION = '';
-    const RELEASE_DATE = '2020-06-24 21:23:30';
+    const RELEASE_DATE = '2020-07-16 12:57:00';
     const SOURCE_VERSION = '1.10-dev+source';
 
     /**
diff -pruN 1.10.8-1/src/Composer/Repository/Vcs/GitHubDriver.php 1.10.9-1/src/Composer/Repository/Vcs/GitHubDriver.php
--- 1.10.8-1/src/Composer/Repository/Vcs/GitHubDriver.php	2020-07-09 05:46:32.000000000 +0000
+++ 1.10.9-1/src/Composer/Repository/Vcs/GitHubDriver.php	2020-08-02 06:46:43.000000000 +0000
@@ -214,20 +214,19 @@ class GitHubDriver extends VcsDriver
         $result = array();
         $key = null;
         foreach (preg_split('{\r?\n}', $funding) as $line) {
-            $line = preg_replace('{#.*}', '', $line);
             $line = trim($line);
             if (preg_match('{^(\w+)\s*:\s*(.+)$}', $line, $match)) {
-                if (preg_match('{^\[.*\]$}', $match[2])) {
-                    foreach (array_map('trim', preg_split('{[\'"]?\s*,\s*[\'"]?}', substr($match[2], 1, -1))) as $item) {
+                if (preg_match('{^\[(.*)\](?:\s*#.*)?$}', $match[2], $match2)) {
+                    foreach (array_map('trim', preg_split('{[\'"]?\s*,\s*[\'"]?}', $match2[1])) as $item) {
                         $result[] = array('type' => $match[1], 'url' => trim($item, '"\' '));
                     }
-                } else {
-                    $result[] = array('type' => $match[1], 'url' => trim($match[2], '"\' '));
+                } elseif (preg_match('{^([^#].*?)(\s+#.*)?$}', $match[2], $match2)) {
+                    $result[] = array('type' => $match[1], 'url' => trim($match2[1], '"\' '));
                 }
                 $key = null;
-            } elseif (preg_match('{^(\w+)\s*:$}', $line, $match)) {
+            } elseif (preg_match('{^(\w+)\s*:\s*#\s*$}', $line, $match)) {
                 $key = $match[1];
-            } elseif ($key && preg_match('{^-\s*(.+)$}', $line, $match)) {
+            } elseif ($key && preg_match('{^-\s*(.+)(\s+#.*)?$}', $line, $match)) {
                 $result[] = array('type' => $key, 'url' => trim($match[1], '"\' '));
             }
         }
diff -pruN 1.10.8-1/src/Composer/Util/GitLab.php 1.10.9-1/src/Composer/Util/GitLab.php
--- 1.10.8-1/src/Composer/Util/GitLab.php	2020-07-09 05:46:32.000000000 +0000
+++ 1.10.9-1/src/Composer/Util/GitLab.php	2020-08-02 06:46:43.000000000 +0000
@@ -104,7 +104,7 @@ class GitLab
         }
 
         $this->io->writeError(sprintf('A token will be created and stored in "%s", your password will never be stored', $this->config->getAuthConfigSource()->getName()));
-        $this->io->writeError('To revoke access to this token you can visit '.$originUrl.'/profile/applications');
+        $this->io->writeError('To revoke access to this token you can visit '.$scheme.'://'.$originUrl.'/profile/applications');
 
         $attemptCounter = 0;
 
@@ -116,12 +116,17 @@ class GitLab
                 // 403 is max login attempts exceeded
                 if (in_array($e->getCode(), array(403, 401))) {
                     if (401 === $e->getCode()) {
-                        $this->io->writeError('Bad credentials.');
+                        $response = json_decode($e->getResponse(), true);
+                        if (isset($response['error']) && $response['error'] === 'invalid_grant') {
+                            $this->io->writeError('Bad credentials. If you have two factor authentication enabled you will have to manually create a personal access token');
+                        } else {
+                            $this->io->writeError('Bad credentials.');
+                        }
                     } else {
                         $this->io->writeError('Maximum number of login attempts exceeded. Please try again later.');
                     }
 
-                    $this->io->writeError('You can also manually create a personal token at '.$scheme.'://'.$originUrl.'/profile/personal_access_tokens');
+                    $this->io->writeError('You can also manually create a personal access token enabling the "read_api" scope at '.$scheme.'://'.$originUrl.'/profile/personal_access_tokens');
                     $this->io->writeError('Add it using "composer config --global --auth gitlab-token.'.$originUrl.' <token>"');
 
                     continue;
diff -pruN 1.10.8-1/src/Composer/Util/RemoteFilesystem.php 1.10.9-1/src/Composer/Util/RemoteFilesystem.php
--- 1.10.8-1/src/Composer/Util/RemoteFilesystem.php	2020-07-09 05:46:32.000000000 +0000
+++ 1.10.9-1/src/Composer/Util/RemoteFilesystem.php	2020-08-02 06:46:43.000000000 +0000
@@ -404,7 +404,7 @@ class RemoteFilesystem
         if ($originUrl === 'bitbucket.org'
             && !$this->isPublicBitBucketDownload($fileUrl)
             && substr($fileUrl, -4) === '.zip'
-            && (!$locationHeader || substr($locationHeader, -4) !== '.zip')
+            && (!$locationHeader || substr(parse_url($locationHeader, PHP_URL_PATH), -4) !== '.zip')
             && $contentType && preg_match('{^text/html\b}i', $contentType)
         ) {
             $result = false;
